#define ID3LIB_MAJOR 0
#define ID3LIB_MINOR 0
#define ID3LIB_PATCH 0

#define LIBFLAC_MAJOR 0
#define LIBFLAC_MINOR 0
#define LIBFLAC_PATCH 0

#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef ENABLE_OGG
#undef ENABLE_SYSTEM_LIBFLAC
#undef HAVE_ICONV_OPEN
#undef HAVE_LANGINFO_CODESET
